.. module:: enaml.widgets.group_box

=======================
enaml.widgets.group_box
=======================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    GroupBox


.. autoclass:: GroupBox
